@@ -1,10 +1,10 @@
-package My::DemoNestedSubcommands::Command1::Command1_1;
+package My::DemoNestedSubcommands::Command1::Command1_0;
 use base qw( My::DemoNestedSubcommands::Command1 );
 
 use strict; 
 use warnings;
 
-sub usage_text { 'command1_1: second subcommand of second top-level command' }
+sub usage_text { 'first subcommand of second top-level command' }
 
 sub run { print "running command '" . $_[0]->name . "'"; }
 
