@@ -24,8 +24,8 @@ sub option_spec {
 sub run {
     my ($self, $opts, @args) = @_;
 
-    my $db = $self->session('db');
-    croak "DB not initialized in session" unless $db;
+    my $db = $self->cache->get('db');
+    croak "DB not initialized in cache" unless $db;
 
     my @entries = $db->all_entries();
     my @entries_output;
@@ -37,7 +37,7 @@ sub run {
 
         push @entries_output, $entry_output;
     }
-print 'FIXME: For now, just pretend that this data gets published in the ',
+print 'Pretend that this data gets published in the ',
 'requested format, using a specified template, and sent to a named ',
 "output file\n\n";
     return join("\n", @entries_output) . "\n";
